@@ -54,14 +54,12 @@ def cut_factor(a):
     except:
         print("Error!!!")
         exit()
-    d = a
     while b <= a:
         if a % b == 0:
             a /= b
             c.append(b)
         else:
             b += 1
-    print(str(d) + "=", end="")
     for i in range(len(c) - 1):
         e.append(c[i])
     e.append(c[-1])
