@@ -11,8 +11,6 @@ def clear():
 #         print(i,end="")
 # pr("e"+"1")
 def fun(x,*a):
-    try:
-        x=float(x)
     for j in a:
         for i in range(len(j)):
             print(j[i],end="")
